@@ -78,7 +78,16 @@ class CoordinationDriver(object):
 
     @staticmethod
     def run_watchers(timeout=None):
-        """Run the watchers callback."""
+        """Run the watchers callback.
+
+        This may also activate :py:meth:`.run_elect_coordinator` (depending
+        on driver implementation).
+        """
+        raise tooz.NotImplemented
+
+    @staticmethod
+    def run_elect_coordinator():
+        """Try to leader elect this coordinator & activate hooks on success."""
         raise tooz.NotImplemented
 
     @abc.abstractmethod
@@ -283,6 +292,19 @@ class CoordinationDriver(object):
         """
         raise tooz.NotImplemented
 
+    @staticmethod
+    def get_member_info(group_id, member_id):
+        """Return the statistics and capabilities of a member asynchronously.
+
+        :param group_id: the id of the group of the member
+        :type group_id: str
+        :param member_id: the id of the member
+        :type member_id: str
+        :returns: capabilities and statistics of a member
+        :rtype: CoordAsyncResult
+        """
+        raise tooz.NotImplemented
+
     @staticmethod
     def update_capabilities(group_id, capabilities):
         """Update capabilities of the caller in the specified group
