@@ -21,6 +21,7 @@ import uuid
 
 from concurrent import futures
 import fixtures
+import mock
 import testscenarios
 from testtools import matchers
 from testtools import testcase
@@ -225,6 +226,7 @@ class TestAPI(testscenarios.TestWithScenarios,
         capa = self._coord.get_member_capabilities(self.group_id,
                                                    self.member_id).get()
         self.assertEqual(capa, caps)
+        self.assertEqual(capa['type'], caps['type'])
 
     def test_get_member_capabilities_nonexistent_group(self):
         capa = self._coord.get_member_capabilities(self.group_id,
@@ -241,6 +243,44 @@ class TestAPI(testscenarios.TestWithScenarios,
         self.assertRaises(tooz.coordination.MemberNotJoined,
                           capa.get)
 
+    def test_get_member_info(self):
+        self._coord.create_group(self.group_id).get()
+        self._coord.join_group(self.group_id, b"test_capabilities")
+
+        member_info = self._coord.get_member_info(self.group_id,
+                                                  self.member_id).get()
+        self.assertEqual(member_info['capabilities'], b"test_capabilities")
+
+    def test_get_member_info_complex(self):
+        self._coord.create_group(self.group_id).get()
+        caps = {
+            'type': 'warrior',
+            'abilities': ['fight', 'flight', 'double-hit-damage'],
+        }
+        member_info = {'capabilities': 'caps',
+                       'created_at': '0',
+                       'updated_at': '0'}
+        self._coord.join_group(self.group_id, caps)
+        member_info = self._coord.get_member_info(self.group_id,
+                                                  self.member_id).get()
+        self.assertEqual(member_info['capabilities'], caps)
+
+    def test_get_member_info_nonexistent_group(self):
+        member_info = self._coord.get_member_info(self.group_id,
+                                                  self.member_id)
+        # Drivers raise one of those depending on their capability
+        self.assertRaisesAny([tooz.coordination.MemberNotJoined,
+                              tooz.coordination.GroupNotCreated],
+                             member_info.get)
+
+    def test_get_member_info_nonjoined_member(self):
+        self._coord.create_group(self.group_id).get()
+        member_id = self._get_random_uuid()
+        member_info = self._coord.get_member_info(self.group_id,
+                                                  member_id)
+        self.assertRaises(tooz.coordination.MemberNotJoined,
+                          member_info.get)
+
     def test_update_capabilities(self):
         self._coord.create_group(self.group_id).get()
         self._coord.join_group(self.group_id, b"test_capabilities1").get()
@@ -682,6 +722,63 @@ class TestAPI(testscenarios.TestWithScenarios,
         with lock1:
             self.assertFalse(lock2.acquire(blocking=False))
 
+    def test_get_lock_context_fails(self):
+        name = self._get_random_uuid()
+        lock1 = self._coord.get_lock(name)
+        lock2 = self._coord.get_lock(name)
+        with mock.patch.object(lock2, 'acquire', return_value=False):
+            with lock1:
+                self.assertRaises(
+                    tooz.coordination.LockAcquireFailed,
+                    lock2.__enter__)
+
+    def test_get_lock_context_check_value(self):
+        name = self._get_random_uuid()
+        lock = self._coord.get_lock(name)
+        with lock as returned_lock:
+            self.assertEqual(lock, returned_lock)
+
+    def test_lock_context_manager_acquire_no_argument(self):
+        name = self._get_random_uuid()
+        lock1 = self._coord.get_lock(name)
+        lock2 = self._coord.get_lock(name)
+        with lock1():
+            self.assertFalse(lock2.acquire(blocking=False))
+
+    def test_lock_context_manager_acquire_argument_return_value(self):
+        name = self._get_random_uuid()
+        blocking_value = 10.12
+        lock = self._coord.get_lock(name)
+        with lock(blocking_value) as returned_lock:
+            self.assertEqual(lock, returned_lock)
+
+    def test_lock_context_manager_acquire_argument_release_within(self):
+        name = self._get_random_uuid()
+        blocking_value = 10.12
+        lock = self._coord.get_lock(name)
+        with lock(blocking_value) as returned_lock:
+            self.assertTrue(returned_lock.release())
+
+    def test_lock_context_manager_acquire_argument(self):
+        name = self._get_random_uuid()
+        blocking_value = 10.12
+        lock = self._coord.get_lock(name)
+        with mock.patch.object(lock, 'acquire', wraps=True, autospec=True) as \
+                mock_acquire:
+            with lock(blocking_value):
+                mock_acquire.assert_called_once_with(blocking_value)
+
+    def test_lock_context_manager_acquire_argument_timeout(self):
+        name = self._get_random_uuid()
+        lock1 = self._coord.get_lock(name)
+        lock2 = self._coord.get_lock(name)
+        with lock1:
+            try:
+                with lock2(False):
+                    self.fail('Lock acquire should have failed')
+            except tooz.coordination.LockAcquireFailed:
+                pass
+
     def test_get_lock_locked_twice(self):
         name = self._get_random_uuid()
         lock = self._coord.get_lock(name)
